Import

Enum Import 

pub enum Import<'a> {
    ByName {
        hint: usize,
        name: &'a CStr,
    },
    ByOrdinal {
        ord: u16,
    },
}
Imported symbol.

Variants



ByName

Imported by name.

The hint is an index in the export names table that may contain the desired symbol. For more information see this blog post by Raymond Chen.

Fields

hint: usize
name: &'a CStr


ByOrdinal

Imported by ordinal.

Fields

ord: u16